diff --git a/Bloxstrap/ViewModels/FastFlagsViewModel.cs b/Bloxstrap/ViewModels/FastFlagsViewModel.cs
index a60c5a4..6531153 100644
--- a/Bloxstrap/ViewModels/FastFlagsViewModel.cs
+++ b/Bloxstrap/ViewModels/FastFlagsViewModel.cs
@@ -53,7 +53,11 @@ namespace Bloxstrap.ViewModels
if (value)
{
- App.FastFlags.SetRenderingMode("Direct3D 11");
+ if (!(App.FastFlags.GetValue("FFlagDebugGraphicsPreferD3D11") == "True" || App.FastFlags.GetValue("FFlagDebugGraphicsPreferD3D11FL10") == "True"))
+ {
+ App.FastFlags.SetRenderingMode("Direct3D 11");
+ }
+
OnPropertyChanged(nameof(SelectedRenderingMode));
}
}
diff --git a/Bloxstrap/Views/Pages/FastFlagsPage.xaml b/Bloxstrap/Views/Pages/FastFlagsPage.xaml
index 1f435dc..50deec3 100644
--- a/Bloxstrap/Views/Pages/FastFlagsPage.xaml
+++ b/Bloxstrap/Views/Pages/FastFlagsPage.xaml
@@ -65,7 +65,7 @@
-
+
diff --git a/Bloxstrap/Singletons/FastFlagManager.cs b/Bloxstrap/Singletons/FastFlagManager.cs
index d158752..4a5b26f 100644
--- a/Bloxstrap/Singletons/FastFlagManager.cs
+++ b/Bloxstrap/Singletons/FastFlagManager.cs
@@ -20,6 +20,7 @@ namespace Bloxstrap.Singletons
{
{ "Automatic", "" },
{ "Direct3D 11", "FFlagDebugGraphicsPreferD3D11" },
+ { "Direct3D 10", "FFlagDebugGraphicsPreferD3D11FL10" },
{ "Vulkan", "FFlagDebugGraphicsPreferVulkan" },
{ "OpenGL", "FFlagDebugGraphicsPreferOpenGL" }
};
@@ -120,9 +121,14 @@ namespace Bloxstrap.Singletons
if (GetValue("DFIntTaskSchedulerTargetFps") is null)
SetValue("DFIntTaskSchedulerTargetFps", 9999);
- // reshade / exclusive fullscreen requires direct3d 11 to work
- if (GetValue(RenderingModes["Direct3D 11"]) != "True" && App.FastFlags.GetValue("FFlagHandleAltEnterFullscreenManually") == "False")
- SetRenderingMode("Direct3D 11");
+ // exclusive fullscreen requires direct3d 10/11 to work
+ if (App.FastFlags.GetValue("FFlagHandleAltEnterFullscreenManually") == "False")
+ {
+ if (!(App.FastFlags.GetValue("FFlagDebugGraphicsPreferD3D11") == "True" || App.FastFlags.GetValue("FFlagDebugGraphicsPreferD3D11FL10") == "True"))
+ {
+ SetRenderingMode("Direct3D 11");
+ }
+ }
}
public override void Save()